export * from './service.ts';
import { type AIGatewayChatCompletion, type AIGatewayChatCompletionParams, type AIGatewayCompletionTextResult, type AIGatewayModels, type AIGatewayProviderFamily, type AIGatewayRequestOptions, type AIGatewayRequestResponse, type AIGatewayResponseSchemaInput, type AIGatewayStreamingCompletion } from './service.ts';
import { type Logger } from '@agentuity/client';
import { z } from 'zod';
export declare const AIGatewayClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type AIGatewayClientOptions = z.infer<typeof AIGatewayClientOptionsSchema>;
export declare class AIGatewayClient {
    #private;
    constructor(options?: AIGatewayClientOptions);
    listModels(): Promise<AIGatewayModels>;
    complete(params: AIGatewayChatCompletionParams): Promise<AIGatewayChatCompletion>;
    completeText(params: AIGatewayChatCompletionParams): Promise<AIGatewayCompletionTextResult & {
        completion: AIGatewayChatCompletion;
    }>;
    completeStructured<T = unknown>(params: AIGatewayChatCompletionParams & {
        response_schema: AIGatewayResponseSchemaInput;
    }): Promise<{
        data: T | undefined;
        completion: AIGatewayChatCompletion;
        family: AIGatewayProviderFamily;
    }>;
    request<T = unknown>(options: AIGatewayRequestOptions): Promise<AIGatewayRequestResponse<T>>;
    streamRequest(options: AIGatewayRequestOptions): Promise<AIGatewayStreamingCompletion>;
}
//# sourceMappingURL=index.d.ts.map