import { z } from 'zod';
declare const service: {
    name: string;
    slug: string;
    description: string;
    host: string;
    hasPublicEndpoints: boolean;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                success: z.ZodBoolean;
                data: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    name: z.ZodString;
                    created: z.ZodOptional<z.ZodNumber>;
                    api: z.ZodOptional<z.ZodString>;
                    family: z.ZodOptional<z.ZodString>;
                    context_window: z.ZodOptional<z.ZodNumber>;
                    max_output_tokens: z.ZodOptional<z.ZodNumber>;
                    input_modalities: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    output_modalities: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    attachment: z.ZodOptional<z.ZodBoolean>;
                    reasoning: z.ZodOptional<z.ZodBoolean>;
                    tool_call: z.ZodOptional<z.ZodBoolean>;
                    temperature: z.ZodOptional<z.ZodBoolean>;
                    knowledge: z.ZodOptional<z.ZodString>;
                    open_weights: z.ZodOptional<z.ZodBoolean>;
                    recommended: z.ZodOptional<z.ZodBoolean>;
                    default_for: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    rank: z.ZodOptional<z.ZodNumber>;
                    provider: z.ZodOptional<z.ZodObject<{
                        env: z.ZodOptional<z.ZodArray<z.ZodString>>;
                        api: z.ZodOptional<z.ZodString>;
                        doc: z.ZodOptional<z.ZodString>;
                        logo_url: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    pricing: z.ZodOptional<z.ZodObject<{
                        input: z.ZodNumber;
                        output: z.ZodNumber;
                        cached_input: z.ZodOptional<z.ZodNumber>;
                        unit: z.ZodString;
                        currency: z.ZodString;
                    }, z.core.$strip>>;
                }, z.core.$strip>>>>;
                message: z.ZodOptional<z.ZodString>;
                error: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        public: boolean;
        responseHeaders?: undefined;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    model: z.ZodString;
                    input: z.ZodOptional<z.ZodUnknown>;
                    contents: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
                    messages: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        role: z.ZodEnum<{
                            system: "system";
                            developer: "developer";
                            user: "user";
                            assistant: "assistant";
                            tool: "tool";
                        }>;
                        content: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodObject<{
                            type: z.ZodString;
                        }, z.core.$catchall<z.ZodUnknown>>>, z.ZodNull]>>;
                        name: z.ZodOptional<z.ZodString>;
                        tool_call_id: z.ZodOptional<z.ZodString>;
                        tool_calls: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
                    }, z.core.$strip>>>;
                    prompt: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodString>]>>;
                    temperature: z.ZodOptional<z.ZodNumber>;
                    top_p: z.ZodOptional<z.ZodNumber>;
                    max_tokens: z.ZodOptional<z.ZodNumber>;
                    stream: z.ZodOptional<z.ZodBoolean>;
                    stop: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodString>]>>;
                    response_format: z.ZodOptional<z.ZodUnknown>;
                    response_schema: z.ZodOptional<z.ZodUnion<readonly [z.ZodObject<{
                        name: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        strict: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodUnion<readonly [z.ZodRecord<z.ZodString, z.ZodUnknown>, z.ZodCustom<{
                            '~standard': unknown;
                        }, {
                            '~standard': unknown;
                        }>]>;
                    }, z.core.$strip>, z.ZodRecord<z.ZodString, z.ZodUnknown>, z.ZodCustom<{
                        '~standard': unknown;
                    }, {
                        '~standard': unknown;
                    }>]>>;
                }, z.core.$catchall<z.ZodUnknown>>;
                overrides?: undefined;
            };
        };
        responseDescription: string;
        responseHeaders: {
            name: string;
            description: string;
        }[];
        responseFields: {
            schema: z.ZodObject<{
                id: z.ZodOptional<z.ZodString>;
                object: z.ZodOptional<z.ZodString>;
                created: z.ZodOptional<z.ZodNumber>;
                model: z.ZodOptional<z.ZodString>;
                choices: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
                usage: z.ZodOptional<z.ZodUnknown>;
                agentuity: z.ZodOptional<z.ZodObject<{
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    cost: z.ZodOptional<z.ZodObject<{
                        total: z.ZodOptional<z.ZodNumber>;
                        unit: z.ZodOptional<z.ZodString>;
                        inputQuantity: z.ZodOptional<z.ZodNumber>;
                        outputQuantity: z.ZodOptional<z.ZodNumber>;
                        promptTokens: z.ZodOptional<z.ZodNumber>;
                        completionTokens: z.ZodOptional<z.ZodNumber>;
                        reasoningTokens: z.ZodOptional<z.ZodNumber>;
                    }, z.core.$strip>>;
                }, z.core.$strip>>;
            }, z.core.$catchall<z.ZodUnknown>>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            model: string;
            messages: {
                role: string;
                content: string;
            }[];
            max_tokens: number;
            stream?: undefined;
        };
        public?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    model: z.ZodString;
                    input: z.ZodOptional<z.ZodUnknown>;
                    contents: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
                    messages: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        role: z.ZodEnum<{
                            system: "system";
                            developer: "developer";
                            user: "user";
                            assistant: "assistant";
                            tool: "tool";
                        }>;
                        content: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodObject<{
                            type: z.ZodString;
                        }, z.core.$catchall<z.ZodUnknown>>>, z.ZodNull]>>;
                        name: z.ZodOptional<z.ZodString>;
                        tool_call_id: z.ZodOptional<z.ZodString>;
                        tool_calls: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
                    }, z.core.$strip>>>;
                    prompt: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodString>]>>;
                    temperature: z.ZodOptional<z.ZodNumber>;
                    top_p: z.ZodOptional<z.ZodNumber>;
                    max_tokens: z.ZodOptional<z.ZodNumber>;
                    stop: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodArray<z.ZodString>]>>;
                    response_format: z.ZodOptional<z.ZodUnknown>;
                    response_schema: z.ZodOptional<z.ZodUnion<readonly [z.ZodObject<{
                        name: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        strict: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodUnion<readonly [z.ZodRecord<z.ZodString, z.ZodUnknown>, z.ZodCustom<{
                            '~standard': unknown;
                        }, {
                            '~standard': unknown;
                        }>]>;
                    }, z.core.$strip>, z.ZodRecord<z.ZodString, z.ZodUnknown>, z.ZodCustom<{
                        '~standard': unknown;
                    }, {
                        '~standard': unknown;
                    }>]>>;
                    stream: z.ZodLiteral<true>;
                }, z.core.$catchall<z.ZodUnknown>>;
                overrides: {
                    stream: {
                        type: string;
                    };
                };
            };
        };
        responseDescription: string;
        responseHeaders: {
            name: string;
            description: string;
        }[];
        responseFields: {
            schema: z.ZodObject<{
                choices: z.ZodArray<z.ZodObject<{
                    delta: z.ZodOptional<z.ZodObject<{
                        role: z.ZodOptional<z.ZodString>;
                        content: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    finish_reason: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                }, z.core.$catchall<z.ZodUnknown>>>;
            }, z.core.$catchall<z.ZodUnknown>>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleHeaders: {
            Accept: string;
        };
        exampleBody: {
            model: string;
            messages: {
                role: string;
                content: string;
            }[];
            stream: boolean;
            max_tokens?: undefined;
        };
        public?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map